@@ -11,6 +11,6 @@ int main()
     WvFile infile("/etc/passwd", O_RDONLY);
     char *s;
     
-    while (infile.isok() && (s = infile.getline(-1)) != NULL)
+    while (infile.isok() && (s = infile.blocking_getline(-1)) != NULL)
     	wvcon->print("%s\n", s);
 }
