@@ -15,7 +15,7 @@
  *
  */
 #include "wvhttp.h"
-#include "wvstreamlist.h"
+#include "wvistreamlist.h"
 #include "wvlog.h"
 #include "wvfile.h"
 
@@ -30,7 +30,7 @@ int main(int argc, char **argv)
     static char buf[10240];
     size_t len;
 
-    WvStreamList l;
+    WvIStreamList l;
     l.add_after(l.tail, &http, false);
 
     while (http.isok() && out.isok())
