@@ -7,9 +7,9 @@ int main(int argc, char **argv)
 {
     wvcrash_setup(argv[0]);    
 
-    WvCRLMgr crl;
+    WvCRL crl;
     crl.isok();
-    
+#if 0    
     WvX509Mgr ca("o=ca", 1024);
     ca.create_selfsigned(true);
     crl.setca(&ca);
@@ -34,6 +34,6 @@ int main(int argc, char **argv)
     fprintf(stderr,"And user cert should be revoked\n");
     crl.isrevoked(user.get_serial());
     fprintf(stderr,"And should still be revoked!\n"); 
-
+#endif
     return 0;
 }
