@@ -19,10 +19,11 @@
 class UniReadOnlyGen : public UniFilterGen
 {
 public:
-    UniReadOnlyGen(UniConfGen *inner) : UniFilterGen(inner) { }
+    UniReadOnlyGen(IUniConfGen *inner) : UniFilterGen(inner) { }
 
     /***** Overridden members *****/
 
+    virtual void flush_buffers() { }
     virtual void set(const UniConfKey &key, WvStringParm value) { };
 };
 
