@@ -42,7 +42,7 @@ public:
 	      int _keep_for = 7, bool _force_new_line = false,
               bool _allow_append = true);
     
-    void start_log();
+    WvString start_log();
 
 private:
     virtual void _make_prefix(time_t now_sec); 
