@@ -14,6 +14,7 @@
 
 #include <openssl/rsa.h>
 #include <openssl/x509.h>
+#include <openssl/ocsp.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -26,6 +27,8 @@ DSA *wv_d2i_DSAPrivateKey(DSA **a, const unsigned char **pp, long length);
 X509_REQ *wv_d2i_X509_REQ(X509_REQ **a, const unsigned char **pp, long length);    
 X509 *wv_d2i_X509(X509 **a, unsigned char **pp, long length);
 
+int wv_i2d_OCSP_REQUEST_bio(BIO *bio, OCSP_REQUEST *req);
+
 
 #ifdef __cplusplus
 };
