@@ -11,7 +11,14 @@
 #define UNSTABLE
 #endif
 
-#ifndef _WIN32
+#ifdef _WIN32
+#include <time.h>
+#include <winsock2.h>
+#include <ws2tcpip.h>
+#include "wvwin32-sanitize.h"
+#else
+#include <unistd.h> // not strictly necessary, but EVERYBODY uses this...
+#include <sys/time.h>
 #include "wvautoconf.h"
 #endif
 
