@@ -3,39 +3,50 @@
  *   Copyright (C) 1997-2002 Net Integration Technologies, Inc.
  */
 #include "wvunixsocket.h"
+#include "wvunixlistener.h"
 #include "wvistreamlist.h"
 #include "wvlog.h"
 
-static void stream_bounce_to_list(WvStream &s, void *userdata)
+static void stream_bounce_to_list(WvStream *in, WvIStreamList *list,
+				  WvStringParm localaddr)
 {
-    WvIStreamList &l = *(WvIStreamList *)userdata;
-    WvIStreamList::Iter out(l);
+    WvIStreamList::Iter out(*list);
     char *line;
 
-    while ((line = s.getline()) != NULL)
+    while ((line = in->getline()) != NULL)
     {
 	if (!strncmp(line, "quit", 4))
 	{
-	    s.close();
+	    in->close();
 	    continue;
 	}
 	
 	for (out.rewind(); out.next(); )
 	{
-	    if (&out() != &s && out->iswritable())
+	    if (&out() != in && out->iswritable())
 	    {
-		static_cast<WvStream*>(&out())->print("%s> %s\n", 
-			    s.src() ? (WvString)*s.src() : WvString("stdin"),
-			    line);
-		if (s.src())
+		static_cast<WvStream*>(&out())->print(
+		    "%s> %s\n",
+		    in->src() ? (WvString)*in->src() : WvString("stdin"),
+		    line);
+		if (localaddr)
 		    wvcon->print("Local address of source was %s\n",
-				 ((WvUnixConn *)&s)->localaddr());
+				 localaddr);
 	    }
 	}
     }
 }
 
 
+static void accept_callback(WvIStreamList *list, IWvStream *_s)
+{
+    WvStreamClone *s = new WvStreamClone(_s);
+    s->setcallback(wv::bind(stream_bounce_to_list, s, list, 
+                  ((WvUnixConn *)_s)->localaddr()));
+    list->append(s, true, "WvUnixConn");
+}
+
+
 int main(int argc, char **argv)
 {
     {
@@ -45,8 +56,8 @@ int main(int argc, char **argv)
 	WvUnixListener sock(argc==2 ? argv[1] : "/tmp/fuzzy",
 			    0777);
 	
-	wvin->setcallback(stream_bounce_to_list, &l);
-	sock.auto_accept(&l, stream_bounce_to_list, &l);
+	wvin->setcallback(wv::bind(stream_bounce_to_list, wvin, &l, NULL));
+	sock.onaccept(wv::bind(accept_callback, &l, _1));
 	
 	log("Listening on port %s\n", *sock.src());
 	
