@@ -30,18 +30,14 @@ WvUDPStream::WvUDPStream(const WvIPPortAddr &_local,
     int x = 1;
     setfd(socket(PF_INET, SOCK_DGRAM, 0));
     if (getfd() < 0 
-#ifndef _WIN32
-	|| fcntl(getfd(), F_SETFD, 1)
-	|| fcntl(getfd(), F_SETFL, O_RDWR | O_NONBLOCK)
-#else
-	|| ioctlsocket(getfd(), FIONBIO, (u_long*) &x) // non-blocking
-#endif        
-	|| setsockopt(getfd(), SOL_SOCKET, SO_REUSEADDR, &x, sizeof(x)) < 0
-	)
+	|| setsockopt(getfd(), SOL_SOCKET, SO_REUSEADDR, &x, sizeof(x)) < 0)
     {
 	seterr(errno);
 	return;
     }
+    
+    set_close_on_exec(true);
+    set_nonblock(true);
 
     struct sockaddr *sa = _local.sockaddr();
     if (bind(getfd(), sa, _local.sockaddr_len()))
