@@ -215,7 +215,7 @@ WVTEST_MAIN("outbuf_limit")
 }
 
 
-static void myclosecb(int *i, WvStream &s)
+static void myclosecb(int *i)
 {
     (*i)++;
 }
@@ -224,8 +224,7 @@ WVTEST_MAIN("closecallback")
 {
     WvFdStream s(dup(0), dup(1));
     int i = 0;
-    s.setclosecallback(
-	       WvBoundCallback<IWvStreamCallback,int*>(&myclosecb, &i));
+    s.setclosecallback(wv::bind(&myclosecb, &i));
     
     WVPASS(s.isok());
     s.nowrite();
@@ -261,8 +260,7 @@ public:
     {
 	WVPASS(isreadable());
         called = false;
-        setcallback(WvStreamCallback(this,
-        	&FooFD::fooback), NULL);
+        setcallback(wv::bind(&FooFD::fooback, this));
         WvIStreamList::globallist.append(this, false, "FooFD");
     }
 
@@ -271,7 +269,7 @@ public:
 	WvIStreamList::globallist.unlink(this);
     }
 
-    void fooback(WvStream &, void *)
+    void fooback()
     {
 	called = true;
     }
