@@ -9,19 +9,19 @@
 #include "wvlog.h"
 #include <sys/time.h>
 
-WvLog log("timeouttest", WvLog::Info);
+WvLog mylog("timeouttest", WvLog::Info);
 
-void timeout(WvStream &s, void *userdata)
+void timeout()
 {
     static int count = 0;
     count++;
-    log("Fire %s\n", count);
+    mylog("Fire %s\n", count);
 }
 
 int main()
 {
     WvTimeoutStream t(1000);
-    t.setcallback(timeout, NULL);
+    t.setcallback(timeout);
 
     free(malloc(1));
   
