@@ -10,23 +10,23 @@
 #include "wvlog.h"
 #include <sys/time.h>
 
-WvLog log("timetest", WvLog::Info);
+WvLog mylog("timetest", WvLog::Info);
 bool want_to_quit = false;
 unsigned int count = 0;
 
-void timer_callback(WvStream& s, void*)
+void timer_callback(WvStream& s)
 {
     if (s.alarm_was_ticking)
     {
-	log("X ");
+	mylog("X ");
 	s.alarm(200);
     }
     else
     {
 	if (!(count % 10))
-	    log("\n");
+	    mylog("\n");
 
-	log("%02s ", count);
+	mylog("%02s ", count);
 
 	if (++count >= 100)
 	    want_to_quit = true;
@@ -39,9 +39,9 @@ int main()
     
     free(malloc(1));
     
-    log("Artificial burstiness test - should take exactly 10 seconds\n");
+    mylog("Artificial burstiness test - should take exactly 10 seconds\n");
 
-    t.setcallback(timer_callback, 0);
+    t.setcallback(wv::bind(timer_callback, wv::ref(t)));
     t.set_timer(100);
     t.alarm(200);
 
