@@ -18,17 +18,30 @@
 #pragma init_seg(lib)
 #endif
 
-static IWvStream *creator(WvStringParm s)
+static IWvStream *creator(WvStringParm s, IObject *_obj)
 {
-    return new WvStreamClone(wvcreate<IWvStream>(s));
+    return new WvStreamClone(wvcreate<IWvStream>(s, _obj));
 }
 
-static WvMoniker<IWvStream> reg("clone", creator);
+static IWvStream *objcreator(WvStringParm s, IObject *_obj)
+{
+    // no real need to wrap it
+#if MUTATE_ISNT_BROKEN
+    return mutate<IWvStream>(_obj);
+#else
+    // HACK: we assume the object is safely of type IWvStream because
+    // xplc's mutate<> function seems not to be working for some reason.
+    return (IWvStream *)_obj;
+#endif
+}
+
+static WvMoniker<IWvStream> clonereg("clone", creator);
+static WvMoniker<IWvStream> objreg("obj", objcreator);
+static WvMoniker<IWvStream> objreg2("", objcreator);
 
 
 WvStreamClone::WvStreamClone(IWvStream *_cloned) 
-    : cloned(0), 
-      disassociate_on_close(false), 
+    : cloned(NULL),
       my_type("WvStreamClone:(none)")
 {
     setclone(_cloned);
@@ -40,8 +53,8 @@ WvStreamClone::WvStreamClone(IWvStream *_cloned)
 WvStreamClone::~WvStreamClone()
 {
     //fprintf(stderr, "%p destroying: clone is %p\n", this, cloned);
+    setclone(NULL);
     close();
-    WVRELEASE(cloned);
 }
 
 
@@ -73,8 +86,6 @@ void WvStreamClone::close()
     if (cloned)
 	cloned->setclosecallback(0); // prevent recursion!
     WvStream::close();
-    if (disassociate_on_close)
-        setclone(NULL);
     if (cloned)
 	cloned->close();
 }
@@ -155,18 +166,15 @@ WvString WvStreamClone::errstr() const
 }
 
 
-void WvStreamClone::close_callback(WvStream &s)
+void WvStreamClone::close_callback()
 {
-    if (cloned == &s)
-    {
-	//fprintf(stderr, "streamclone-closecb: %d/%d/%d/%d/%d\n",
-	//	stop_read, stop_write, outbuf.used(), inbuf.used(), closed);
-	nowrite();
-	noread();
-	// close();
-	//fprintf(stderr, "streamclone-closecb2: %d/%d/%d/%d/%d\n",
-	//	stop_read, stop_write, outbuf.used(), inbuf.used(), closed);
-    }
+    //fprintf(stderr, "streamclone-closecb: %d/%d/%d/%d/%d\n",
+    //	stop_read, stop_write, outbuf.used(), inbuf.used(), closed);
+    nowrite();
+    noread();
+    // close();
+    //fprintf(stderr, "streamclone-closecb2: %d/%d/%d/%d/%d\n",
+    //	stop_read, stop_write, outbuf.used(), inbuf.used(), closed);
 }
 
 
@@ -174,10 +182,12 @@ void WvStreamClone::setclone(IWvStream *newclone)
 {
     if (cloned)
 	cloned->setclosecallback(0);
+    WVRELEASE(cloned);
     cloned = newclone;
     closed = stop_read = stop_write = false;
     if (cloned)
-	cloned->setclosecallback(IWvStreamCallback(this, &WvStreamClone::close_callback));
+	cloned->setclosecallback(wv::bind(&WvStreamClone::close_callback,
+					  this));
     
     if (newclone != NULL)
         my_type = WvString("WvStreamClone:%s", newclone->wstype());
@@ -195,9 +205,9 @@ void WvStreamClone::pre_select(SelectInfo &si)
     {
 	if (!si.inherit_request)
 	{
-	    si.wants.readable |= readcb;
-	    si.wants.writable |= writecb;
-	    si.wants.isexception |= exceptcb;
+	    si.wants.readable |= static_cast<bool>(readcb);
+	    si.wants.writable |= static_cast<bool>(writecb);
+	    si.wants.isexception |= static_cast<bool>(exceptcb);
 	}
 	
 	if (outbuf.used() || autoclose_time)
@@ -224,9 +234,9 @@ bool WvStreamClone::post_select(SelectInfo &si)
     {
 	if (!si.inherit_request)
 	{
-	    si.wants.readable |= readcb;
-	    si.wants.writable |= writecb;
-	    si.wants.isexception |= exceptcb;
+	    si.wants.readable |= static_cast<bool>(readcb);
+	    si.wants.writable |= static_cast<bool>(writecb);
+	    si.wants.isexception |= static_cast<bool>(exceptcb);
 	}
 
 	val = cloned->post_select(si);
@@ -264,3 +274,12 @@ void WvStreamClone::execute()
     WvStream::execute();
     if (cloned) cloned->callback();
 }
+
+WvString WvStreamClone::getattr(WvStringParm name) const
+{
+    WvString ret = WvStream::getattr(name);
+    if (ret.isnull() && cloned)
+	return cloned->getattr(name);
+
+    return ret;
+}
