@@ -21,7 +21,6 @@
 #include "uniclientconn.h"
 #include "unisecuregen.h"
 #include "unipermgen.h"
-#include "wvx509mgr.h"
 #include "uniconfroot.h"
 #include "wvstrutils.h"
 #include "wvfileutils.h"
@@ -31,6 +30,12 @@
 #include "slp.h"
 #endif
 
+#include <map>
+
+using std::map;
+using wv::shared_ptr;
+
+
 #ifdef _WIN32
 #pragma comment(linker, "/include:?UniRegistryGenMoniker@@3V?$WvMoniker@VIUniConfGen@@@@A")
 #pragma comment(linker, "/include:?UniPStoreGenMoniker@@3V?$WvMoniker@VIUniConfGen@@@@A")
@@ -40,17 +45,21 @@
 #define DEFAULT_CONFIG_FILE "ini:uniconf.ini"
 
 
-static WvMap<WvString, IUniConfGen*> namedgens(42);
+static map<WvString, shared_ptr<IUniConfGen> > namedgens;
 
 
-static IUniConfGen *creator(WvStringParm s)
+static IUniConfGen *creator(WvStringParm s, IObject*)
 {
-    IUniConfGen* gen = namedgens[s];
+    map<WvString, shared_ptr<IUniConfGen> >::iterator it = namedgens.find(s);
+    shared_ptr<IUniConfGen> gen;
+
+    if (it != namedgens.end())
+	gen = it->second;
 
     if (gen)
 	gen->addRef();
 
-    return gen;
+    return gen.get();
 }
 
 WvMoniker<IUniConfGen> UniNamedMoniker("named", creator);
@@ -59,9 +68,8 @@ WvMoniker<IUniConfGen> UniNamedMoniker("named", creator);
 class UniConfd : public WvStreamsDaemon
 {
     bool needauth;
-    int port;
-    int sslport;
-    WvString unixport, permmon, unix_mode;
+    WvString permmon;
+    WvStringList lmonikers;
     time_t commit_interval;
 
     UniConfRoot cfg;
@@ -82,21 +90,24 @@ class UniConfd : public WvStreamsDaemon
 	*ptr = 0;
 	moniker = ptr + 1;
 
-	namedgens.add(name, wvcreate<IUniConfGen>(moniker), true);
+	namedgens[name] = shared_ptr<IUniConfGen>(
+	    wvcreate<IUniConfGen>(moniker),
+	    wv::bind(&IUniConfGen::release, _1));
+
 	return true;
     }
 
-    void commit_stream_cb(WvStream &s, void *)
+    void commit_stream_cb(WvStream *s)
     {
 	cfg.commit();
 	cfg.refresh();
 	if (permgen)
 	    permgen->refresh();
 	    
-        s.alarm(commit_interval * 1000);
+        s->alarm(commit_interval * 1000);
     }
     
-    void startup(WvStreamsDaemon &, void *)
+    void startup()
     {
         if (first_time)
         {
@@ -131,70 +142,21 @@ class UniConfd : public WvStreamsDaemon
         
         UniConfDaemon *daemon = new UniConfDaemon(cfg, needauth, permgen);
         add_die_stream(daemon, true, "uniconfd");
-
-#ifndef _WIN32
-        if (!!unixport)
-        {
-	    // FIXME: THIS IS NOT SAFE!
-	    mkdirp(getdirname(unixport));
-	    ::unlink(unixport);
-	    if (!daemon->setupunixsocket(unixport))
-	        exit(3);
-	    if (!!unix_mode && unix_mode.num())
-	    {
-	        log("Setting mode on %s to: %s\n", unixport, unix_mode);
-	        mode_t mode;
-	        sscanf(unix_mode.edit(), "%o", &mode);
-	        chmod(unixport, mode);
-	    }
-        }
-#endif
-
-        if (port && !daemon->setuptcpsocket(WvIPPortAddr("0.0.0.0", port)))
-        {
-	    die();
+	
+	if (lmonikers.isempty())
+	{
+	    log(WvLog::Critical, "Can't start: no listeners given!\n");
+	    die(7);
 	    return;
 	}
 
-        if (sslport)
-        {
-            WvString dName = encode_hostname_as_DN(fqdomainname());
-            WvX509Mgr *x509cert = new WvX509Mgr(dName, 1024);
-            if (!x509cert->isok())
-            {
-                log(WvLog::Critical,
-		    "Couldn't generate X509 certificate: SSL not available.\n");
-	        die();
-	        return;
-            }
-            else if (!daemon->setupsslsocket(
-		        WvIPPortAddr("0.0.0.0", sslport), x509cert))
-	    {
-	        die();
-	        return;
-	    }
-        }
-    
-#ifdef WITH_SLP
-        WvSlp slp;
+	WvStringList::Iter i(lmonikers);
+	for (i.rewind(); i.next(); )
+	    daemon->listen(*i);
 
-        if (first_time)
-        {
-            // Now that we're this far...
-            
-            // Register UniConf service with SLP 
-            if (port)
-	        slp.add_service("uniconf.niti", fqdomainname(), port);
-        
-            // Register UniConf SSL service with SLP 
-            if (sslport)
-	        slp.add_service("uniconfs.niti", fqdomainname(), sslport);
-	}
-#endif
-    
         WvStream *commit_stream = new WvStream;
-        commit_stream->setcallback(WvStreamCallback(this,
-                &UniConfd::commit_stream_cb), NULL);
+        commit_stream->setcallback(wv::bind(&UniConfd::commit_stream_cb, this,
+					    commit_stream));
         commit_stream->alarm(commit_interval * 1000);
         add_die_stream(commit_stream, true, "commit");
         
@@ -204,15 +166,13 @@ class UniConfd : public WvStreamsDaemon
     
 public:
 
-    UniConfd() :
-            WvStreamsDaemon("uniconfd", VERBOSE_PACKAGE_VERSION,
-                WvStreamsDaemonCallback(this, &UniConfd::startup)),
-            needauth(false),
-            port(DEFAULT_UNICONF_DAEMON_TCP_PORT),
-            sslport(DEFAULT_UNICONF_DAEMON_SSL_PORT),
-            commit_interval(5*60),
-            first_time(true),
-            permgen(NULL)
+    UniConfd():
+	WvStreamsDaemon("uniconfd", VERBOSE_WVPACKAGE_VERSION,
+			wv::bind(&UniConfd::startup, this)),
+	needauth(false),
+	commit_interval(5*60),
+	first_time(true),
+	permgen(NULL)
     {
         args.add_option(0, "pid-file",
                 "Specify the .pid file to use (only applies with --daemonize)", "filename",
@@ -222,26 +182,15 @@ public:
         args.add_option('A', "check-access",
                 "Check all accesses against perms moniker", "moniker",
                 permmon);
-        args.add_option('p', "tcp",
-                "Listen on given TCP port (default=4111; 0 to disable)", "port",
-                port);
-        args.add_option('s', "ssl",
-                "Listen on given TCP/SSL port (default=4112; 0 to disable)", "port",
-                sslport);
-#ifndef _WIN32
-        args.add_option('u', "unix",
-                "Listen on given Unix socket filename (default=disabled)", "filename",
-                unixport);
-        args.add_option('m', "unix-mode",
-                "Set the Unix socket to 'mode' (default to uniconfd users umask)", "mode",
-                unix_mode);
+	args.add_option('l', "listen",
+		"Listen on the given socket (eg. tcp:4111, ssl:tcp:4112)",
+		"lmoniker", lmonikers);
 	args.add_option('n', "named-gen",
-		"creates a \"named\" moniker 'name' from 'moniker'",
-		"name=moniker",
-		WvArgs::ArgCallback(this, &UniConfd::namedgen_cb), NULL);
-#endif
+			"creates a \"named\" moniker 'name' from 'moniker'",
+			"name=moniker",
+			wv::bind(&UniConfd::namedgen_cb, this, _1, _2), NULL);
 	args.add_optional_arg("MONIKERS", true);
-	args.set_email("<" PACKAGE_BUGREPORT ">");
+	args.set_email("<" WVPACKAGE_BUGREPORT ">");
     }
     
     
