@@ -2,7 +2,7 @@
 #include "uniconfgen.h"
 #include "wvmoniker.h"
 
-static void cb(const UniConfKey &, WvStringParm, void *)
+static void cb(const UniConfKey &, WvStringParm)
 {
 }
 
@@ -12,6 +12,9 @@ WVTEST_MAIN("null generator, setcallback, delete")
     IUniConfGen *gen = wvcreate<IUniConfGen>("null:");
     WVPASS(gen);
     if (gen)
-	gen->setcallback(cb, NULL);
+    {
+	gen->add_callback(gen, cb);
+	gen->del_callback(gen);
+    }
     WVRELEASE(gen);
 }
