@@ -9,4 +9,12 @@ int main()
 
     root["foo"].setme("baz");
     printf("foo = \"%s\"\n", root["foo"].getme().cstr());
+
+    UniConfRoot r("temp:");
+
+    UniConf uu;
+
+    UniConfKey k;
+
+    printf("root: %d uu: %d k: %d\n", sizeof(r), sizeof(uu), sizeof(k));
 }
