@@ -19,13 +19,13 @@ UUID_MAP_BEGIN(UniConfGen)
 
 UniConfGen::UniConfGen()
 {
-    cbdata = NULL;
     hold_nesting = 0;
 }
 
 
 UniConfGen::~UniConfGen()
 {
+    assert(cblist.isempty());
 }
 
 
@@ -70,8 +70,7 @@ void UniConfGen::flush_delta()
 
 void UniConfGen::dispatch_delta(const UniConfKey &key, WvStringParm value)
 {
-    if (cb)
-        cb(key, value, cbdata);
+    cblist(key, value);
 }
 
 
@@ -91,6 +90,14 @@ void UniConfGen::delta(const UniConfKey &key, WvStringParm value)
 }
 
 
+void UniConfGen::setv_naive(const UniConfPairList &pairs)
+{
+    UniConfPairList::Iter pair(pairs);
+    for (pair.rewind(); pair.next(); )
+	set(pair->key(), pair->value());
+}
+
+
 bool UniConfGen::haschildren(const UniConfKey &key)
 {
     bool children = false;
@@ -148,11 +155,16 @@ bool UniConfGen::isok()
 }
 
 
-void UniConfGen::setcallback(const UniConfGenCallback &callback,
-			     void *userdata)
+void UniConfGen::add_callback(void *cookie,
+			      const UniConfGenCallback &callback)
 {
-    cb = callback;
-    cbdata = userdata;
+    cblist.add(callback, cookie);
+}
+
+
+void UniConfGen::del_callback(void *cookie)
+{
+    cblist.del(cookie);
 }
 
 
@@ -251,38 +263,3 @@ UniConfGen::Iter *UniConfGen::recursiveiterator(const UniConfKey &key)
 }
 
 
-UniConfGen::ListIter::ListIter(IUniConfGen *_gen)
-    : ki(keys), vi(values)
-{
-    gen = _gen;
-}
-
-
-void UniConfGen::ListIter::rewind()
-{
-    ki.rewind();
-    vi.rewind();
-}
-
-
-bool UniConfGen::ListIter::next()
-{
-    if (vi.cur())
-	vi.next();
-    return ki.next();
-}
-
-
-UniConfKey UniConfGen::ListIter::key() const
-{
-    return *ki;
-}
-
-
-WvString UniConfGen::ListIter::value() const
-{
-    if (vi.cur())
-	return *vi;
-    else
-	return gen->get(*ki);
-}
