@@ -76,7 +76,7 @@ public:
 WV_LINK(UniFsTreeGen);
 
 
-static IUniConfGen *creator(WvStringParm s)
+static IUniConfGen *creator(WvStringParm s, IObject *)
 {
     return new UniAutoMountGen(s);
 }
