@@ -9,8 +9,11 @@
 #include "wvlog.h"
 #include "wvstringcache.h"
 #include "unilistiter.h"
+#include "wvlinkerhack.h"
 
-static IUniConfGen *creator(WvStringParm)
+WV_LINK(UniTempGen);
+
+static IUniConfGen *creator(WvStringParm, IObject*)
 {
     return new UniTempGen();
 }
@@ -80,8 +83,9 @@ void UniTempGen::set(const UniConfKey &_key, WvStringParm _value)
             {
                 hold_delta();
                 // Issue notifications for every key that gets deleted.
-                node->visit(UniConfValueTree::Visitor(this,
-                    &UniTempGen::notify_deleted), NULL, false, true);
+                node->visit(wv::bind(&UniTempGen::notify_deleted, this,
+				     _1, _2),
+			    NULL, false, true);
                 delete node;
                 if (node == root)
                     root = NULL;
