@@ -10,7 +10,7 @@
 #include <signal.h>
 
 
-static WvLog log("http2test", WvLog::Info);
+static WvLog mylog("http2test", WvLog::Info);
 static bool want_to_die = false;
 
 static void sighandler_die(int signum)
@@ -22,10 +22,10 @@ static void sighandler_die(int signum)
 }
 
 
-static void close_callback(WvStream& s)
+static void close_callback(WvStream *s)
 {
-    if (!s.isok())
-	log(WvLog::Error, "%s\n", s.geterr());
+    if (!s->isok())
+	mylog(WvLog::Error, "%s\n", s->geterr());
 }
 
 
@@ -71,7 +71,7 @@ int main(int argc, char **argv)
 					   O_CREAT|O_WRONLY|O_TRUNC);
 		    assert(!f->readable);
 		    s->autoforward(*f);
-		    s->setclosecallback(close_callback);
+		    s->setclosecallback(wv::bind(close_callback, s));
 		    l.append(s, true, "url");
 		    l.append(f, true, "file");
 		}
@@ -80,7 +80,7 @@ int main(int argc, char **argv)
     }
     
     if (!p.isok() && p.geterr())
-	log("HttpPool: %s\n", p.errstr());
+	mylog("HttpPool: %s\n", p.errstr());
     
     return 0;
 }
