@@ -315,7 +315,7 @@ WvString url_decode(WvStringParm str, bool no_space)
  
     const char *iptr;
     char *optr;
-    char *idx1, *idx2;
+    const char *idx1, *idx2;
     static const char hex[] = "0123456789ABCDEF";
     WvString in, intmp(str), out;
 
@@ -967,7 +967,7 @@ WvString afterstr(WvStringParm line, WvStringParm a)
     if (!line || !a)
 	return WvString::null;
 
-    char *loc = strstr(line, a);
+    const char *loc = strstr(line, a);
     if (loc == 0)
 	return "";
 
@@ -984,8 +984,8 @@ WvString beforestr(WvStringParm line, WvStringParm a)
 	return WvString::null;
 
     WvString ret = line;
-    ret.unique();     
-    char *loc = strstr(ret, a);
+    ret.unique();
+    char *loc = strstr(ret.edit(), a);
 
     if (loc == 0)
 	return line;
