@@ -13,18 +13,14 @@ WVTEST_MAIN("passwd_crypttest.cc")
     srandom(time(0));
 #endif
 
-
-    char *blank, *word, *longword;
-    WvString blank_result1, blank_result2, word_result, longword_result;
-
-    blank = "";
-    word = "12345678";
-    longword = "1234567890000000000000000000000000000";
+    const char *blank = "";
+    const char *word = "12345678";
+    const char *longword = "1234567890000000000000000000000000000";
     
-    blank_result1 = passwd_crypt(blank);
-    blank_result2 = passwd_crypt(blank);
-    word_result = passwd_crypt(word);
-    longword_result = passwd_crypt(longword);
+    WvString blank_result1 = passwd_crypt(blank);
+    WvString blank_result2 = passwd_crypt(blank);
+    WvString word_result = passwd_crypt(word);
+    WvString longword_result = passwd_crypt(longword);
 
  
     WVPASS(!!blank_result1 && blank_result1 != "*");
@@ -39,17 +35,14 @@ WVTEST_MAIN("passwd_md5test.cc")
 {
     srandom(time(0));
 
-    char *blank, *word, *longword;
-    WvString blank_result1, blank_result2, word_result, longword_result;
-
-    blank = "";
-    word = "12345678";
-    longword = "1234567890000000000000000000000000000";
+    const char *blank = "";
+    const char *word = "12345678";
+    const char *longword = "1234567890000000000000000000000000000";
     
-    blank_result1 = passwd_md5(blank);
-    blank_result2 = passwd_md5(blank);
-    word_result = passwd_md5(word);
-    longword_result = passwd_md5(longword);
+    WvString blank_result1 = passwd_md5(blank);
+    WvString blank_result2 = passwd_md5(blank);
+    WvString word_result = passwd_md5(word);
+    WvString longword_result = passwd_md5(longword);
 
  
     WVPASS(!!blank_result1 && blank_result1 != "*");
