@@ -1,24 +1,24 @@
-#include "wvcallback.h"
+#include "wvtr1.h"
 #include <stdio.h>
 
 struct A
 {
-    int x, y;
-    A(int _x = 0, int _y = 0)
+    long x, y;
+    A(long _x = 0, long _y = 0)
         { x = _x; y = _y; }
     
     A add(const A &a)
         { return A(x+a.x, y+a.y); }
 };
 
-typedef WvCallback<A, const A &, void *> ACallback;
-typedef WvCallback<A, const A &> A2Callback;
-typedef WvCallback<A, void *> A3Callback;
+typedef wv::function<A(const A&, void*)> ACallback;
+typedef wv::function<A(const A&)> A2Callback;
+typedef wv::function<A(void *)> A3Callback;
 
 
 static A bunk(const A &a, void *userdata)
 {
-    int incr = (int)userdata;
+    long incr = (long)userdata;
     return A(a.x+incr, a.y+incr*2);
 }
 
@@ -32,7 +32,7 @@ static A bunk1(const A &a)
 
 static void print_a(const A &a)
 {
-    printf("result: %d/%d\n", a.x, a.y);
+    printf("result: %ld/%ld\n", a.x, a.y);
 }
 
 
@@ -45,7 +45,7 @@ int main()
     // FIXME: I am broken. Please show this to somebody
     // who can fix.... can fix.... can fix.....
     // A3Callback c2(WvBoundCallback<A3Callback, const A &>(bunk, a));
-    A2Callback c3(&a, &A::add);
+    A2Callback c3(wv::bind(&A::add, &a, _1));
     
     print_a(c0(a, (void *)5));
     print_a(c1(a));
