@@ -8,9 +8,7 @@ int main()
     int guard4 = 0;
     printf("Before: %d %d %d %d\n", guard1, guard2, guard3, guard4);
     WvDirIter i("/");
-    assert(!guard1);
-    assert(!guard2);
-    assert(!guard3);
-    assert(!guard4);
+    WvDirIter *i2 = new WvDirIter("/");
     printf("After: %d %d %d %d\n", guard1, guard2, guard3, guard4);
+    delete i2;
 }
