@@ -17,8 +17,7 @@ int main(int argc, char **argv)
 
     WvEncoder *enc = new WvWordWrapEncoder(maxwidth);
 
-    WvEncoderStream *stream = new WvEncoderStream(wvout);
-    stream->disassociate_on_close = true;
+    WvEncoderStream *stream = new WvEncoderStream((wvout->addRef(), wvout));
     stream->auto_flush(false);
     stream->writechain.append(enc, true);
 
