@@ -61,3 +61,11 @@ WvString WvStringList::popstr()
     unlink_first();
     return s;
 }
+
+
+#ifndef _WIN32
+void WvStringList::split(WvStringParm s, const WvRegex &regex, int limit)
+{
+    return ::strcoll_split(*this, s, regex, limit);
+}
+#endif
