@@ -150,8 +150,11 @@ int WvTest::run_all(const char * const *prefixes)
     /* I should be doing something to do with SetTimer here, 
      * not sure exactly what just yet */
 #else
-    signal(SIGALRM, alarm_handler);
-    // signal(SIGALRM, SIG_IGN);
+    char *disable(getenv("WVTEST_DISABLE_TIMEOUT"));
+    if (disable != NULL && disable[0] != '\0' && disable[0] != '0')
+        signal(SIGALRM, SIG_IGN);
+    else
+        signal(SIGALRM, alarm_handler);
     alarm(MAX_TEST_TIME);
 #endif
     start_time = time(NULL);
@@ -189,6 +192,11 @@ int WvTest::run_all(const char * const *prefixes)
 		|| prefix_match(cur->descr, prefixes)))
 	{
 #ifndef _WIN32
+            // set SIGPIPE back to default, helps catch tests which don't set
+            // this signal to SIG_IGN (which is almost always what you want)
+            // on startup
+            signal(SIGPIPE, SIG_DFL);
+
             pid_t child = 0;
             if (run_twice)
             {
@@ -198,7 +206,7 @@ int WvTest::run_all(const char * const *prefixes)
             }
 #endif
 
-	    printf("Testing \"%s\" in %s:\n", cur->descr, cur->idstr);
+	    printf("\nTesting \"%s\" in %s:\n", cur->descr, cur->idstr);
 	    fflush(stdout);
 	    
 	    cur->main();
@@ -240,7 +248,9 @@ int WvTest::run_all(const char * const *prefixes)
 	}
     }
     
-    if (prefixes && *prefixes)
+    WVPASS(runs > 0);
+    
+    if (prefixes && *prefixes && **prefixes)
 	printf("WvTest: WARNING: only ran tests starting with "
 	       "specifed prefix(es).\n");
     else
@@ -391,6 +401,7 @@ bool WvTest::start_check_eq(const char *file, int line,
     return cond;
 }
 
+
 bool WvTest::start_check_lt(const char *file, int line,
 			    const char *a, const char *b)
 {
